@@ -185,6 +185,11 @@ class UserDetails(LoggedInRESTAPIView, GenericAPIView):
         Optional: email, first_name, last_name and UserProfile fields
     Returns the updated UserProfile and/or User object.
     """
+    if get_user_profile_model():
+        serializer_class = get_user_profile_update_serializer()
+    else:
+        serializer_class = UserUpdateSerializer
+
     def get_profile_serializer_class(self):
         return get_user_profile_serializer()
 
@@ -236,6 +241,7 @@ class PasswordReset(LoggedOutRESTAPIView, GenericAPIView):
     """
 
     serializer_class = PasswordResetSerializer
+    password_reset_form_class = PasswordResetForm
 
     def post(self, request):
         # Create a serializer with request.DATA
@@ -243,7 +249,7 @@ class PasswordReset(LoggedOutRESTAPIView, GenericAPIView):
 
         if serializer.is_valid():
             # Create PasswordResetForm with the serializer
-            reset_form = PasswordResetForm(data=serializer.data)
+            reset_form = self.password_reset_form_class(data=serializer.data)
 
             if reset_form.is_valid():
                 # Sett some values to trigger the send_email method.
